Module alloc_mut

Module alloc_mut 

Mutable allocation traits.

These are automatically implemented for A: Alloc, so you only need to implement them if your allocator requires mutable access to perform operations.

Due to this, they are also broader than the alloc traits.

Traits

AllocMut
A memory allocation interface which may require mutable access to itself to perform operations.
BasicAllocMut
A memory allocation interface which may require mutable access and can allocate and deallocate.
DeallocMut
A memory allocation interface which may require mutable access to itself and can also deallocate memory.
FullAllocMut
A memory allocation interface which may require mutable access and can allocate, deallocate, and arbitrarily resize allocations.
GrowMut
A memory allocation interface which may require mutable access to itself and can also grow allocations.
ReallocMut
A memory allocation interface which may require mutable access to itself and can arbitrarily resize allocations.
ShrinkMut
A memory allocation interface which may require mutable access to itself and can also shrink allocations.