BasicAllocMut

Trait BasicAllocMut 

pub trait BasicAllocMut: AllocMut + DeallocMut { }
A memory allocation interface which may require mutable access and can allocate and deallocate.

This exists solely because it reads more nicely than A: DeallocMut; the two are the same.

Implementors