FullAllocMut

Trait FullAllocMut 

pub trait FullAllocMut:
    ReallocMut
    + GrowMut
    + ShrinkMut
    + AllocMut
    + DeallocMut { }
A memory allocation interface which may require mutable access and can allocate, deallocate, and arbitrarily resize allocations.

This exists solely because it reads more nicely than A: ReallocMut; the two are the same.

Implementors