ZstBasicAlloc

Trait ZstBasicAlloc 

pub trait ZstBasicAlloc:
    ZstAlloc
    + ZstDealloc
    + BasicAlloc { }
A stateless memory allocation interface which can allocate and deallocate.

This exists solely because it is somewhat clearer to read than A: ZstDealloc; the two are the same.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors