Traits
- Alloc
Mut - A memory allocation interface which may require mutable access to itself to perform operations.
- Basic
Alloc Mut - A memory allocation interface which may require mutable access and can allocate and deallocate.
- Dealloc
Mut - A memory allocation interface which may require mutable access to itself and can also deallocate memory.
- Full
Alloc Mut - A memory allocation interface which may require mutable access and can allocate, deallocate, and arbitrarily resize allocations.
- GrowMut
- A memory allocation interface which may require mutable access to itself and can also grow allocations.
- Realloc
Mut - A memory allocation interface which may require mutable access to itself and can arbitrarily resize allocations.
- Shrink
Mut - A memory allocation interface which may require mutable access to itself and can also shrink allocations.