pub unsafe trait UnsizedCopy { }Expand description
Unsafe marker trait for types that can be copied, including unsized types such as slices.
Safety
The implementor must ensure Self has a memory representation which can be duplicated without
violating soundness or causing double frees.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".